"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.JWTVerify = exports.parseJwtFromAuthorizationHeader = void 0;
const jose_1 = require("jose");
const url_1 = require("url");
const errors_1 = require("./errors");
__exportStar(require("./errors"), exports);
__exportStar(require("./logger"), exports);
__exportStar(require("./handlers"), exports);
__exportStar(require("./types"), exports);
__exportStar(require("./database/abstractRepository"), exports);
__exportStar(require("./database/abstractDataSource"), exports);
function parseJwtFromAuthorizationHeader(req) {
    const authorization_header = req.header('Authorization');
    if (authorization_header === undefined) {
        throw new errors_1.JWTVerificationError('Authorization header is not set', 401);
    }
    const bearerTokenResult = /^Bearer (.*)$/.exec(authorization_header);
    if (bearerTokenResult === null || bearerTokenResult.length != 2) {
        throw new errors_1.JWTVerificationError('Authorization header is malformed', 401);
    }
    const jwt = bearerTokenResult[1];
    if (!jwt)
        throw new errors_1.JWTVerificationError('No JWT provided', 401);
    return jwt;
}
exports.parseJwtFromAuthorizationHeader = parseJwtFromAuthorizationHeader;
function JWTVerify(options, validatePayload, parseJwt) {
    const jwksUrl = new url_1.URL(options.JWKS_URL);
    const JWKS = (0, jose_1.createRemoteJWKSet)(jwksUrl);
    return async (req, scopes) => {
        const jwt = parseJwt(req);
        if (!jwt)
            throw new errors_1.JWTVerificationError('No JWT provided', 401);
        const jwtVerifyResult = await (0, jose_1.jwtVerify)(jwt, JWKS, {
            issuer: options.SECURITY_ISSUER,
            audience: options.SECURITY_AUDIENCE,
        });
        const user = jwtVerifyResult.payload;
        user.jwt = jwt;
        if (!validatePayload(user))
            throw new errors_1.JWTVerificationError('Payload is malformed', 401);
        let scopeFound = false;
        for (const scope of scopes) {
            if (user.scopes.includes(scope)) {
                scopeFound = true;
                break;
            }
        }
        if (!scopeFound)
            throw new errors_1.JWTVerificationError('Missing Scope: one of ' + scopes, 403);
        return user;
    };
}
exports.JWTVerify = JWTVerify;
//# sourceMappingURL=index.js.map